// Copyright (C) 1992 James H. Price, All rights reserved
//
//  BARTEST.CPP
//
//    Test program for TitleLine
//

#define Uses_MsgBox
#define Uses_TEvent
#define Uses_TApplication
#define Uses_TKeys
#define Uses_TRect
#define Uses_TMenu
#define Uses_TMenuBar
#define Uses_TMenuItem
#define Uses_TStatusLine
#define Uses_TStatusItem
#define Uses_TStatusDef
#define Uses_TDeskTop
#include <tv.h>

#include "titlelin.h"

const cmAbout = 100;
const cmTest  = 101;

class Shell : public TApplication {

public:

  Shell();
  static TMenuBar *initMenuBar( TRect r );
  static TStatusLine *initStatusLine( TRect r );
  void handleEvent( TEvent& event );
  void idle();

private:

  TitleLine *t;

  void About();
  void Test();
};

Shell::Shell() : TProgInit (
      &Shell::initStatusLine,
      &Shell::initMenuBar,
      &Shell::initDeskTop
      )
{
  TRect r = deskTop->getBounds();     // get size of deskTop
  ++r.a.y;                            // compensate for title line
  deskTop->setBounds( r );

  r = getExtent();
  r.b.y = r.a.y + 1;                  // put title at top
  t = new TitleLine( r, "TitleLine Demo" );
  insert(t);
}

TMenuBar *Shell::initMenuBar( TRect r )
{
  ++r.a.y;                // move the menu down one line
  r.b.y = r.a.y + 1;

  TMenuItem& mI =
    *new TMenuItem( "~T~est", cmTest, kbNoKey, hcNoContext );

  return new TMenuBar( r, new TMenu( mI ) );
}

TStatusLine *Shell::initStatusLine( TRect r )
{
  r.a.y = r.b.y - 1;

  TStatusLine *sL = new TStatusLine( r,
    *new TStatusDef(0, 0xFFFF) +
      *new TStatusItem( 0, kbF10, cmMenu ) +
      *new TStatusItem( "~Alt-X~ Quit", kbAltX, cmQuit ) );

  return sL;
}

void Shell::handleEvent( TEvent &event )
{
  TApplication::handleEvent(event);

  if (event.what == evCommand)
  {
    switch (event.message.command)
    {
      case cmAbout:
        About();
        break;
      case cmTest:
        Test();
        break;
      default:
        break;
    }
  }
}

void Shell::idle()
{
  TProgram::idle();

  // select menu bar if deskTop empty

  if( deskTop->current == 0
  && !menuBar->getState( sfSelected ) )
  {
    TEvent event;
    event.what = evCommand;
    event.message.command = cmMenu;   // put a cmMenu event in queue
    putEvent( event );
  }
}

void Shell::About()
{
  messageBox( "\003TitleLine Demo",
    mfInformation | mfOKButton );
}

void Shell::Test()
{
  // Update the title line
  t->setTitle( "TitleLine Demo: ~Test~" );

  // do something
  messageBox( "\003Function Test() is executing",
    mfInformation | mfOKButton );

  // restore previous title
  t->setTitle( "TitleLine Demo" );
}

int main()
{
  TEvent init;
  init.what = evCommand;
  init.message.command = cmAbout;     // make a cmAbout command event

  Shell shell;
  shell.putEvent(init);               // put it in the queue to pop up
  shell.run();                        // About box when program starts
  return 0;
}

